@@ -3,7 +3,7 @@
 # Univention Management Console
 #  OpenID Connect implementation for the UMC
 #
-# Copyright 2022-2024 Univention GmbH
+# Copyright 2022-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -147,7 +147,7 @@ class OIDCResource(OAuth2Mixin, Resource):
                 code_verifier=code_verifier,
             )
         except HTTPClientError as exc:
-            CORE.error('Could not get access token: %s' % (exc.response.body,))
+            CORE.error('Could not get access token: %s' % (exc.response and exc.response.body or exc,))
             raise OpenIDProvideUnavailable(self._('Could not receive token from authorization server.'))
 
         try:
@@ -340,7 +340,7 @@ class OIDCResource(OAuth2Mixin, Resource):
             )
         except HTTPClientError:
             raise  # handled in get()
-        # TODO why do we need that, see univention/ucs#2388
+        # TODO: why do we need that, see univention/ucs#2388
         http_client.close()
         return escape.json_decode(response.body)
 
