@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 #
-# Copyright 2022-2024 Univention GmbH
+# Copyright 2022-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -373,7 +373,7 @@ class Resource(RequestHandler):
             index = message.find('Traceback') if 'Traceback' in message else message.find('File')
             message, stacktrace = message[:index].strip(), message[index:].strip()
         if stacktrace:
-            CORE.error('%s', (stacktrace,))
+            CORE.error('%s', stacktrace)
         if ucr.is_false('umc/http/show_tracebacks', False):
             stacktrace = None
 
